aboutsummaryrefslogtreecommitdiffstats
path: root/lib/Net
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Net')
-rw-r--r--lib/Net/IMAP/InterIMAP.pm (renamed from lib/Net/IMAP/Sync.pm)6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/Net/IMAP/Sync.pm b/lib/Net/IMAP/InterIMAP.pm
index 6561a66..26cfbbd 100644
--- a/lib/Net/IMAP/Sync.pm
+++ b/lib/Net/IMAP/InterIMAP.pm
@@ -16,7 +16,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------
-package Net::IMAP::Sync v0.0.1;
+package Net::IMAP::InterIMAP v0.0.1;
use warnings;
use strict;
@@ -195,7 +195,7 @@ our $IMAP_cond;
our $IMAP_text;
# Create a new Net::IMAP::Sync object. Connect to the server,
# upgrade to a secure connection (STARTTLS), LOGIN/AUTHENTICATE if needed, and
# update the CAPABILITY list.
# In addition to the %OPTIONS above, valid parameters include:
@@ -384,7 +384,7 @@ sub new($%) {
}
# Log out when the Net::IMAP::Sync object is destroyed.
sub DESTROY($) {
my $self = shift;
foreach (qw/STDIN STDOUT/) {
@@ -195,7 +195,7 @@ our $IMAP_cond;
our $IMAP_text;
-# Create a new Net::IMAP::Sync object. Connect to the server,
+# Create a new Net::IMAP::InterIMAP object. Connect to the server,
# upgrade to a secure connection (STARTTLS), LOGIN/AUTHENTICATE if needed, and
# update the CAPABILITY list.
@@ -384,7 +384,7 @@ sub new($%) {
}
-# Log out when the Net::IMAP::Sync object is destroyed.
+# Log out when the Net::IMAP::InterIMAP object is destroyed.
sub DESTROY($) {
my $self = shift;